"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const ts = require("typescript");
exports.transformerFactory = (context) => (bundle) => {
    // used to keep track if enum is an ambient declaration
    let ambient = false;
    let global = false;
    function visitor(node) {
        switch (node.kind) {
            case ts.SyntaxKind.SourceFile:
                ambient = node.isDeclarationFile;
                global = !ts.isExternalModule(node);
            // falls through;
            case ts.SyntaxKind.Bundle:
            case ts.SyntaxKind.ModuleBlock:
                return ts.visitEachChild(node, visitor, context);
            case ts.SyntaxKind.ModuleDeclaration:
                const savedGlobal = global;
                const savedAmbient = ambient;
                if (!ambient) {
                    const modifierFlags = ts.getCombinedModifierFlags(node);
                    if (!global && (modifierFlags & ts.ModifierFlags.Export) === 0 && (node.flags & ts.NodeFlags.NestedNamespace) === 0)
                        return node;
                    ambient = (modifierFlags & ts.ModifierFlags.Ambient) !== 0;
                }
                global = false;
                node = ts.visitEachChild(node, visitor, context);
                global = savedGlobal;
                ambient = savedAmbient;
                return node;
            case ts.SyntaxKind.EnumDeclaration:
                if (ambient || global || ts.getCombinedModifierFlags(node) & ts.ModifierFlags.Export)
                    return ts.visitEachChild(node, visitor, context);
                return node; // local const enums don't need to be modified
            case ts.SyntaxKind.ConstKeyword:
                return;
            default:
                return node;
        }
    }
    return ts.visitNode(bundle, visitor);
};
function default_1(programOrContext) {
    if ('readEmitHelpers' in programOrContext)
        return exports.transformerFactory(programOrContext);
    return exports.transformerFactory;
}
exports.default = default_1;
//# sourceMappingURL=index.js.map